; -----------------------------------------------------------------------------
; Hola Retro Parla
; -----------------------------------------------------------------------------

; Dirección de memoria donde se carga el programa compilado
org $8000

; Variable de sistema donde están los atributos de la pantalla 1, principal.
ATTR_S:	equ	$5c8d

; Variable de sistema donde está el atributo actual
ATTR_T:	equ	$5c8f

; -----------------------------------------------------------------------------
; Rutina AT de la ROM.
; Posiciona el cursor en las coordenadas especificadas.
;
; Entrada:	B	->	Coordenada Y.
;		C	->	Coordenada X.
;
; Para esta rutina, la esquina superior izquierda de la pantalla es (24, 33).
;
; Altera el valor de los registros A, DE y HL.
; -----------------------------------------------------------------------------
LOCATE:	equ	$0dd9  ;(24,33)

; -----------------------------------------------------------------------------
; Rutina CLS de la ROM.
; Borra la pantalla usando los atributos cargados en la variable .
;
; Altera el valor de los registros AF, BC, DE y HL.
; -----------------------------------------------------------------------------
CLS:	equ	$0daf

; -----------------------------------------------------------------------------
; Inicio del programa
; -----------------------------------------------------------------------------
Inicio:	
	ld	a, $0e		; Carga en A los atributos de flash, brillo, papel y tinta
	ld	hl, ATTR_T	; Carga en HL la dirección de memoria donde se encuentran 
				; los atributos de la pantalla principal
	ld	(hl), a		; Carga en memoria los atributos de la pantalla principal
	
	ld	hl, ATTR_S	; Carga en HL la dirección de memoria donde se encuentran 
				; los atributos actuales
	ld	(hl), a		; Carga en memoria los atributos actuales
	
	ld	a, $02		; Carga en A el color del borde
	out	($fe), a	; Manda al puerto $fe el color del borde
	
	call	CLS		; Limpia la pantalla usando los atributos de ATTR_T
	
	; Para la rutina LOCATE, la esquina superior izquierda está en 24, 31
	ld	b, $18-$0a	; Carga en B la coordenada Y
	ld	c, $1f-$05	; Carga en C la coordenada X
	call	LOCATE		; Posiciona el cursor en las coordenadas X e Y especificadas
	
	ld	hl, Msg		; Carga en HL la primera dirección de memoria del mensaje
	
; -----------------------------------------------------------------------------
; Imprime el mensaje.
;
; Este bucle es de tipo While.
; -----------------------------------------------------------------------------
Bucle:
	ld	a, (hl)		; Carga en A el valor que hay en la posición de memoria apuntada por HL
	or	a		; Comprueba si el valor de A es 0. A OR A = 0 solo si A = 0
	jr	z, Fin		; Si A = 0, salta al fin del programa
	
	rst	$10		; Imprime el carácter cargado en el registro A. Altera el valor del registro AF.
	
	inc	hl		; Incrementa HL para que apunte al siguiente carácter del mensaje
	jr	Bucle		; Salta al inicio de un bucle
	
Fin:
	call	Scroll		; Scroll del mensaje
	;jr 	Fin		; Bucle infinito, para que se vea bien el resultado
	;ret
; -----------------------------------------------------------------------------
; Mensaje que se va a imprimir, terminado en 0 = NULL
; -----------------------------------------------------------------------------
Msg:	defm "Hola Retro Parla!", $00

; -----------------------------------------------------------------------------
; Fichero donde se encuentra la rutina de scroll
; -----------------------------------------------------------------------------
include	"Scroll.asm"

; Directiva de PASMO para que además de incluir un cargador BASIC para el programa
; también lo ejecute al cargarlo	
end $8000