; -----------------------------------------------------------------------------
; Scroll
; Realiza el scroll de la línea 11 (10 en base 0), en un bucle infinito.
; Altera el valor de los registros AF, BC, HL e IX.
; -----------------------------------------------------------------------------
Scroll:
ld	b, $0a		; Carga en B la coordenada Y
ld	c, $00		; Carga en C la coordenada X. El inicio de la línea.
call	GetPointerCoord	; Calcula la posición de memoria

scroll_scan:
ld	c, $08		; Número de scanlines que se van a mover. Un carácter completo.
scroll_col:
ld	b, $20		; Número de columnas que se van a mover. Todas.
scroll_col_loop:
rr	(hl)		; Rota la posición de memoria a la derecha
inc	l		; Incrementa l, pasa a la siguiente columna
djnz	scroll_col_loop	; Hasta que llega a la última columna

jr	nc, scroll_col_nc	; Si no hay acarreo, el bit 0 de la última columna era 0

; Hay acarreo, el bit 0 de la última columna era 1
push	hl		; Pasa el valor del registro HL
pop	ix		; a IX
set	$07, (ix-$20)	; Activa el bit 7 del primer byte de la línea (primer píxel)

; Ha movido el scanline completo
scroll_col_nc:
dec	l		; Vuelve a poner L apuntando a la última columna
ld	a, l		; Carga la línea y columna actuales
and	$e0		; Se queda con la línea
ld	l, a		; Lo carga en L
inc	h		; Pasa al siguiente scanline
dec	c
jr	nz, scroll_col	; Hasta que llega al último scanline

dec	h		; Vuelve a poner H apuntando al scanline 7, y el tercio en el original
ld	a, h		; Carga el valor en A
and	$f8		; Deja la parte del scanline a 0
ld	h, a		; Carga el valor en H
halt			; Espera a que se refresque la pantalla. Comenta esta línea si lo quieres más rápido.

; Llegados aquí, se ha desplazado todo el mensaje un pixel
jr	scroll_scan	; Sigue con el scroll

; -----------------------------------------------------------------------------
; GetPointerCoord
;
; Obtiene la dirección de memoria del primer scanline correspondiente
; a las coordenadas especificadas.
;
; Las posiciones de memoria relativas a la pantalla se disponen de la 
; siguiente manera:	010T TSSS LLLC CCCC
; 			010 es un valor fijo. 
; 			TT es el tercio de la pantalla.
; 			LLL es la línea dentro del tercio.
;			SSS es el scanline de la línea.
;			CCCCC es la columna.
;
; Entrada:	B -> Coordenada Y.
;		C -> Coordenada X.
; Salida:	HL -> Dirección de memoria resultante.
;
; Altera el valor de los registros AF y HL.
; -----------------------------------------------------------------------------
GetPointerCoord:
; En B viene la coordenada Y. 
;	Los bits 0 a 2 son la línea dentro del tercio.
;	Los bits 3 y 4 son el tercio.

ld	h, $40		; Carga en H el valo fijo 0100
ld	a, b		; Carga la coordenada Y en A
and	$18		; Se queda con la parte del tercio
or	h		; Agrega el valor fijo
ld	h, a		; Parte alta de la dirección calculada

ld	a, b		; Carga la coordenada Y en A
and	$07		; Se queda con la parte de la línea 
rrca			
rrca
rrca			; Pasa el valor a los bits 5 a 7
or	c		; Añade la columna
ld	l, a		; Parte baja de la dirección calculada

ret